@@ -1,15 +1,15 @@
 # encoding: utf-8
-"""This module contains :class:`Terminal`, the primary API entry point."""
+"""Module containing :class:`Terminal`, the primary API entry point."""
 # pylint: disable=too-many-lines
 #         Too many lines in module (1027/1000)
 import codecs
 import collections
 import contextlib
-import curses
 import functools
 import io
 import locale
 import os
+import platform
 import select
 import struct
 import sys
@@ -17,21 +17,6 @@ import time
 import warnings
 import re
 
-try:
-    import termios
-    import fcntl
-    import tty
-    HAS_TTY = True
-except ImportError:
-    _TTY_METHODS = ('setraw', 'cbreak', 'kbhit', 'height', 'width')
-    _MSG_NOSUPPORT = (
-        "One or more of the modules: 'termios', 'fcntl', and 'tty' "
-        "are not found on your platform '{0}'. The following methods "
-        "of Terminal are dummy/no-op unless a deriving class overrides "
-        "them: {1}".format(sys.platform.lower(), ', '.join(_TTY_METHODS)))
-    warnings.warn(_MSG_NOSUPPORT)
-    HAS_TTY = False
-
 try:
     InterruptedError
 except NameError:
@@ -74,6 +59,29 @@ from .keyboard import (get_keyboard_sequences,
                        _time_left,
                        )
 
+if platform.system() == 'Windows':
+    import jinxed as curses  # pylint: disable=import-error
+    HAS_TTY = True
+else:
+    import curses
+
+    try:
+        import termios
+        import fcntl
+        import tty
+        HAS_TTY = True
+    except ImportError:
+        _TTY_METHODS = ('setraw', 'cbreak', 'kbhit', 'height', 'width')
+        _MSG_NOSUPPORT = (
+            "One or more of the modules: 'termios', 'fcntl', and 'tty' "
+            "are not found on your platform '{0}'. The following methods "
+            "of Terminal are dummy/no-op unless a deriving class overrides "
+            "them: {1}".format(sys.platform.lower(), ', '.join(_TTY_METHODS)))
+        warnings.warn(_MSG_NOSUPPORT)
+        HAS_TTY = False
+
+_CUR_TERM = None  # See comments at end of file
+
 
 class Terminal(object):
     """
@@ -191,10 +199,13 @@ class Terminal(object):
         self._normal = None  # cache normal attr, preventing recursive lookups
 
         # The descriptor to direct terminal initialization sequences to.
-        self._init_descriptor = (stream_fd is None and
-                                 sys.__stdout__.fileno() or
-                                 stream_fd)
-        self._kind = kind or os.environ.get('TERM', 'unknown')
+        self._init_descriptor = (sys.__stdout__.fileno() if stream_fd is None
+                                 else stream_fd)
+
+        if platform.system() == 'Windows':
+            self._kind = kind or curses.get_term(self._init_descriptor)
+        else:
+            self._kind = kind or os.environ.get('TERM', 'unknown')
 
         if self.does_styling:
             # Initialize curses (call setupterm).
@@ -282,7 +293,11 @@ class Terminal(object):
 
         if self._keyboard_fd is not None:
             # set input encoding and initialize incremental decoder
-            locale.setlocale(locale.LC_ALL, '')
+            if platform.system() == 'Windows' and sys.version_info[0] < 3:
+                # Default for setlocale() has side effects for PY2 on Windows
+                pass
+            else:
+                locale.setlocale(locale.LC_ALL, '')
             self._encoding = locale.getpreferredencoding() or 'ascii'
 
             try:
@@ -426,7 +441,7 @@ class Terminal(object):
             try:
                 if fd is not None:
                     return self._winsize(fd)
-            except IOError:
+            except (IOError, OSError, ValueError, TypeError):
                 pass
 
         return WINSZ(ws_row=int(os.getenv('LINES', '25')),
@@ -1009,8 +1024,8 @@ class Terminal(object):
         A context manager for :func:`tty.setraw`.
 
         Although both :meth:`break` and :meth:`raw` modes allow each keystroke
-        to be read immediately after it is pressed, Raw mode disables processing
-        of input and output.
+        to be read immediately after it is pressed, Raw mode disables
+        processing of input and output.
 
         In cbreak mode, special input characters such as ``^C`` or ``^S`` are
         interpreted by the terminal driver and excluded from the stdin stream.
@@ -1177,6 +1192,7 @@ class WINSZ(collections.namedtuple('WINSZ', (
     _BUF = '\x00' * struct.calcsize(_FMT)
 
 
+#: _CUR_TERM = None
 #: From libcurses/doc/ncurses-intro.html (ESR, Thomas Dickey, et. al)::
 #:
 #:   "After the call to setupterm(), the global variable cur_term is set to
@@ -1196,4 +1212,3 @@ class WINSZ(collections.namedtuple('WINSZ', (
 #: Therefore, the :attr:`Terminal.kind` of each :class:`Terminal` is
 #: essentially a singleton. This global variable reflects that, and a warning
 #: is emitted if somebody expects otherwise.
-_CUR_TERM = None
